@@ -305,7 +305,7 @@ class Payment(metaclass=PoolMeta):
         if self.description:
             return self.description
         elif self.line and self.line.origin:
-            return self.line.origin.rec_name
+            return getattr(self.line.origin, 'rec_name', '')
 
     @property
     def sepa_bank_account_number(self):
